@@ -3,7 +3,7 @@ package Test::Alien::Build;
 use strict;
 use warnings;
 use 5.008004;
-use base qw( Exporter);
+use Exporter qw( import );
 use Path::Tiny qw( path );
 use Carp qw( croak );
 use Test2::API qw( context run_subtest );
@@ -29,7 +29,7 @@ our @EXPORT = qw(
 );
 
 # ABSTRACT: Tools for testing Alien::Build + alienfile
-our $VERSION = '2.37'; # VERSION
+our $VERSION = '2.47'; # VERSION
 
 
 my $build;
@@ -623,7 +623,7 @@ Test::Alien::Build - Tools for testing Alien::Build + alienfile
 
 =head1 VERSION
 
-version 2.37
+version 2.47
 
 =head1 SYNOPSIS
 
@@ -879,7 +879,7 @@ Juan Julián Merelo Guervós (JJ)
 
 Joel Berger (JBERGER)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Lance Wicks (LANCEW)
 
@@ -897,6 +897,8 @@ Paul Evans (leonerd, PEVANS)
 
 Håkon Hægland (hakonhagland, HAKONH)
 
+nick nauwelaerts (INPHOBIA)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
